==> flutter_country_selector-1.0.0.tar.gz: lib/src/localization/localization.dart <==
import 'package:phone_numbers_parser/phone_numbers_parser.dart';

import 'generated/country_selector_localization.dart';

export 'generated/country_selector_localization.dart';
export 'generated/country_selector_localization_en.dart';

extension DynamicLocalization on CountrySelectorLocalization {
  countryName(IsoCode isoCode) {
    return switch (isoCode) {
      IsoCode.AC => ac_,
      IsoCode.AD => ad_,
      IsoCode.AE => ae_,
      IsoCode.AF => af_,
      IsoCode.AG => ag_,
      IsoCode.AI => ai_,
      IsoCode.AL => al_,
      IsoCode.AM => am_,
      IsoCode.AO => ao_,
      IsoCode.AR => ar_,
      IsoCode.AS => as_,
      IsoCode.AT => at_,
      IsoCode.AU => au_,
      IsoCode.AW => aw_,
      IsoCode.AX => ax_,
      IsoCode.AZ => az_,
      IsoCode.BA => ba_,
      IsoCode.BB => bb_,
      IsoCode.BD => bd_,
      IsoCode.BE => be_,
      IsoCode.BF => bf_,
      IsoCode.BG => bg_,
      IsoCode.BH => bh_,
      IsoCode.BI => bi_,
      IsoCode.BJ => bj_,
      IsoCode.BL => bl_,
      IsoCode.BM => bm_,
      IsoCode.BN => bn_,
      IsoCode.BO => bo_,
      IsoCode.BQ => bq_,
      IsoCode.BR => br_,
      IsoCode.BS => bs_,
      IsoCode.BT => bt_,
      IsoCode.BW => bw_,
      IsoCode.BY => by_,
      IsoCode.BZ => bz_,
      IsoCode.CA => ca_,
      IsoCode.CC => cc_,
      IsoCode.CD => cd_,
      IsoCode.CF => cf_,
      IsoCode.CG => cg_,
      IsoCode.CH => ch_,
      IsoCode.CI => ci_,
      IsoCode.CK => ck_,
      IsoCode.CL => cl_,
      IsoCode.CM => cm_,
      IsoCode.CN => cn_,
      IsoCode.CO => co_,
      IsoCode.CR => cr_,
      IsoCode.CU => cu_,
      IsoCode.CV => cv_,
      IsoCode.CW => cw_,
      IsoCode.CX => cx_,
      IsoCode.CY => cy_,
      IsoCode.CZ => cz_,
      IsoCode.DE => de_,
      IsoCode.DJ => dj_,
      IsoCode.DK => dk_,
      IsoCode.DM => dm_,
      IsoCode.DO => do_,
      IsoCode.DZ => dz_,
      IsoCode.EC => ec_,
      IsoCode.EE => ee_,
      IsoCode.EG => eg_,
      IsoCode.EH => eh_,
      IsoCode.ER => er_,
      IsoCode.ES => es_,
      IsoCode.ET => et_,
      IsoCode.FI => fi_,
      IsoCode.FJ => fj_,
      IsoCode.FK => fk_,
      IsoCode.FM => fm_,
      IsoCode.FO => fo_,
      IsoCode.FR => fr_,
      IsoCode.GA => ga_,
      IsoCode.GB => gb_,
      IsoCode.GD => gd_,
      IsoCode.GE => ge_,
      IsoCode.GF => gf_,
      IsoCode.GG => gg_,
      IsoCode.GH => gh_,
      IsoCode.GI => gi_,
      IsoCode.GL => gl_,
      IsoCode.GM => gm_,
      IsoCode.GN => gn_,
      IsoCode.GP => gp_,
      IsoCode.GQ => gq_,
      IsoCode.GR => gr_,
      IsoCode.GT => gt_,
      IsoCode.GU => gu_,
      IsoCode.GW => gw_,
      IsoCode.GY => gy_,
      IsoCode.HK => hk_,
      IsoCode.HN => hn_,
      IsoCode.HR => hr_,
      IsoCode.HT => ht_,
      IsoCode.HU => hu_,
      IsoCode.ID => id_,
      IsoCode.IE => ie_,
      IsoCode.IL => il_,
      IsoCode.IM => im_,
      IsoCode.IN => in_,
      IsoCode.IO => io_,
      IsoCode.IQ => iq_,
      IsoCode.IR => ir_,
      IsoCode.IS => is_,
      IsoCode.IT => it_,
      IsoCode.JE => je_,
      IsoCode.JM => jm_,
      IsoCode.JO => jo_,
      IsoCode.JP => jp_,
      IsoCode.KE => ke_,
      IsoCode.KG => kg_,
      IsoCode.KH => kh_,
      IsoCode.KI => ki_,
      IsoCode.KM => km_,
      IsoCode.KN => kn_,
      IsoCode.KP => kp_,
      IsoCode.KR => kr_,
      IsoCode.KW => kw_,
      IsoCode.KY => ky_,
      IsoCode.KZ => kz_,
      IsoCode.LA => la_,
      IsoCode.LB => lb_,
      IsoCode.LC => lc_,
      IsoCode.LI => li_,
      IsoCode.LK => lk_,
      IsoCode.LR => lr_,
      IsoCode.LS => ls_,
      IsoCode.LT => lt_,
      IsoCode.LU => lu_,
      IsoCode.LV => lv_,
      IsoCode.LY => ly_,
      IsoCode.MA => ma_,
      IsoCode.MC => mc_,
      IsoCode.MD => md_,
      IsoCode.ME => me_,
      IsoCode.MF => mf_,
      IsoCode.MG => mg_,
      IsoCode.MH => mh_,
      IsoCode.MK => mk_,
      IsoCode.ML => ml_,
      IsoCode.MM => mm_,
      IsoCode.MN => mn_,
      IsoCode.MO => mo_,
      IsoCode.MP => mp_,
      IsoCode.MQ => mq_,
      IsoCode.MR => mr_,
      IsoCode.MS => ms_,
      IsoCode.MT => mt_,
      IsoCode.MU => mu_,
      IsoCode.MV => mv_,
      IsoCode.MW => mw_,
      IsoCode.MX => mx_,
      IsoCode.MY => my_,
      IsoCode.MZ => mz_,
      IsoCode.NA => na_,
      IsoCode.NC => nc_,
      IsoCode.NE => ne_,
      IsoCode.NF => nf_,
      IsoCode.NG => ng_,
      IsoCode.NI => ni_,
      IsoCode.NL => nl_,
      IsoCode.NO => no_,
      IsoCode.NP => np_,
      IsoCode.NR => nr_,
      IsoCode.NU => nu_,
      IsoCode.NZ => nz_,
      IsoCode.OM => om_,
      IsoCode.PA => pa_,
      IsoCode.PE => pe_,
      IsoCode.PF => pf_,
      IsoCode.PG => pg_,
      IsoCode.PH => ph_,
      IsoCode.PK => pk_,
      IsoCode.PL => pl_,
      IsoCode.PM => pm_,
      IsoCode.PR => pr_,
      IsoCode.PS => ps_,
      IsoCode.PT => pt_,
      IsoCode.PW => pw_,
      IsoCode.PY => py_,
      IsoCode.QA => qa_,
      IsoCode.RE => re_,
      IsoCode.RO => ro_,
      IsoCode.RS => rs_,
      IsoCode.RU => ru_,
      IsoCode.RW => rw_,
      IsoCode.SA => sa_,
      IsoCode.SB => sb_,
      IsoCode.SC => sc_,
      IsoCode.SD => sd_,
      IsoCode.SE => se_,
      IsoCode.SG => sg_,
      IsoCode.SH => sh_,
      IsoCode.SI => si_,
      IsoCode.SJ => sj_,
      IsoCode.SK => sk_,
      IsoCode.SL => sl_,
      IsoCode.SM => sm_,
      IsoCode.SN => sn_,
      IsoCode.SO => so_,
      IsoCode.SR => sr_,
      IsoCode.SS => ss_,
      IsoCode.ST => st_,
      IsoCode.SV => sv_,
      IsoCode.SX => sx_,
      IsoCode.SY => sy_,
      IsoCode.SZ => sz_,
      IsoCode.TA => ta_,
      IsoCode.TC => tc_,
      IsoCode.TD => td_,
      IsoCode.TG => tg_,
      IsoCode.TH => th_,
      IsoCode.TJ => tj_,
      IsoCode.TK => tk_,
      IsoCode.TL => tl_,
      IsoCode.TM => tm_,
      IsoCode.TN => tn_,
      IsoCode.TO => to_,
      IsoCode.TR => tr_,
      IsoCode.TT => tt_,
      IsoCode.TV => tv_,
      IsoCode.TW => tw_,
      IsoCode.TZ => tz_,
      IsoCode.UA => ua_,
      IsoCode.UG => ug_,
      IsoCode.US => us_,
      IsoCode.UY => uy_,
      IsoCode.UZ => uz_,
      IsoCode.VA => va_,
      IsoCode.VC => vc_,
      IsoCode.VE => ve_,
      IsoCode.VG => vg_,
      IsoCode.VI => vi_,
      IsoCode.VN => vn_,
      IsoCode.VU => vu_,
      IsoCode.WF => wf_,
      IsoCode.WS => ws_,
      IsoCode.XK => xk_,
      IsoCode.YE => ye_,
      IsoCode.YT => yt_,
      IsoCode.ZA => za_,
      IsoCode.ZM => zm_,
      IsoCode.ZW => zw_,
    };
  }
}

==> flutter_country_selector-1.0.7.tar.gz: lib/src/localization/localization.dart <==
import 'package:phone_numbers_parser/metadata.dart';
import 'package:phone_numbers_parser/phone_numbers_parser.dart';

import 'generated/country_selector_localization.dart';

export 'generated/country_selector_localization.dart';
export 'generated/country_selector_localization_en.dart';

extension DynamicLocalization on CountrySelectorLocalization {
  String countryDialCode(IsoCode isoCode) {
    return metadataByIsoCode[isoCode]?.countryCode ?? '';
  }

  String countryName(IsoCode isoCode) {
    return switch (isoCode) {
      IsoCode.AC => ac_,
      IsoCode.AD => ad_,
      IsoCode.AE => ae_,
      IsoCode.AF => af_,
      IsoCode.AG => ag_,
      IsoCode.AI => ai_,
      IsoCode.AL => al_,
      IsoCode.AM => am_,
      IsoCode.AO => ao_,
      IsoCode.AR => ar_,
      IsoCode.AS => as_,
      IsoCode.AT => at_,
      IsoCode.AU => au_,
      IsoCode.AW => aw_,
      IsoCode.AX => ax_,
      IsoCode.AZ => az_,
      IsoCode.BA => ba_,
      IsoCode.BB => bb_,
      IsoCode.BD => bd_,
      IsoCode.BE => be_,
      IsoCode.BF => bf_,
      IsoCode.BG => bg_,
      IsoCode.BH => bh_,
      IsoCode.BI => bi_,
      IsoCode.BJ => bj_,
      IsoCode.BL => bl_,
      IsoCode.BM => bm_,
      IsoCode.BN => bn_,
      IsoCode.BO => bo_,
      IsoCode.BQ => bq_,
      IsoCode.BR => br_,
      IsoCode.BS => bs_,
      IsoCode.BT => bt_,
      IsoCode.BW => bw_,
      IsoCode.BY => by_,
      IsoCode.BZ => bz_,
      IsoCode.CA => ca_,
      IsoCode.CC => cc_,
      IsoCode.CD => cd_,
      IsoCode.CF => cf_,
      IsoCode.CG => cg_,
      IsoCode.CH => ch_,
      IsoCode.CI => ci_,
      IsoCode.CK => ck_,
      IsoCode.CL => cl_,
      IsoCode.CM => cm_,
      IsoCode.CN => cn_,
      IsoCode.CO => co_,
      IsoCode.CR => cr_,
      IsoCode.CU => cu_,
      IsoCode.CV => cv_,
      IsoCode.CW => cw_,
      IsoCode.CX => cx_,
      IsoCode.CY => cy_,
      IsoCode.CZ => cz_,
      IsoCode.DE => de_,
      IsoCode.DJ => dj_,
      IsoCode.DK => dk_,
      IsoCode.DM => dm_,
      IsoCode.DO => do_,
      IsoCode.DZ => dz_,
      IsoCode.EC => ec_,
      IsoCode.EE => ee_,
      IsoCode.EG => eg_,
      IsoCode.EH => eh_,
      IsoCode.ER => er_,
      IsoCode.ES => es_,
      IsoCode.ET => et_,
      IsoCode.FI => fi_,
      IsoCode.FJ => fj_,
      IsoCode.FK => fk_,
      IsoCode.FM => fm_,
      IsoCode.FO => fo_,
      IsoCode.FR => fr_,
      IsoCode.GA => ga_,
      IsoCode.GB => gb_,
      IsoCode.GD => gd_,
      IsoCode.GE => ge_,
      IsoCode.GF => gf_,
      IsoCode.GG => gg_,
      IsoCode.GH => gh_,
      IsoCode.GI => gi_,
      IsoCode.GL => gl_,
      IsoCode.GM => gm_,
      IsoCode.GN => gn_,
      IsoCode.GP => gp_,
      IsoCode.GQ => gq_,
      IsoCode.GR => gr_,
      IsoCode.GT => gt_,
      IsoCode.GU => gu_,
      IsoCode.GW => gw_,
      IsoCode.GY => gy_,
      IsoCode.HK => hk_,
      IsoCode.HN => hn_,
      IsoCode.HR => hr_,
      IsoCode.HT => ht_,
      IsoCode.HU => hu_,
      IsoCode.ID => id_,
      IsoCode.IE => ie_,
      IsoCode.IL => il_,
      IsoCode.IM => im_,
      IsoCode.IN => in_,
      IsoCode.IO => io_,
      IsoCode.IQ => iq_,
      IsoCode.IR => ir_,
      IsoCode.IS => is_,
      IsoCode.IT => it_,
      IsoCode.JE => je_,
      IsoCode.JM => jm_,
      IsoCode.JO => jo_,
      IsoCode.JP => jp_,
      IsoCode.KE => ke_,
      IsoCode.KG => kg_,
      IsoCode.KH => kh_,
      IsoCode.KI => ki_,
      IsoCode.KM => km_,
      IsoCode.KN => kn_,
      IsoCode.KP => kp_,
      IsoCode.KR => kr_,
      IsoCode.KW => kw_,
      IsoCode.KY => ky_,
      IsoCode.KZ => kz_,
      IsoCode.LA => la_,
      IsoCode.LB => lb_,
      IsoCode.LC => lc_,
      IsoCode.LI => li_,
      IsoCode.LK => lk_,
      IsoCode.LR => lr_,
      IsoCode.LS => ls_,
      IsoCode.LT => lt_,
      IsoCode.LU => lu_,
      IsoCode.LV => lv_,
      IsoCode.LY => ly_,
      IsoCode.MA => ma_,
      IsoCode.MC => mc_,
      IsoCode.MD => md_,
      IsoCode.ME => me_,
      IsoCode.MF => mf_,
      IsoCode.MG => mg_,
      IsoCode.MH => mh_,
      IsoCode.MK => mk_,
      IsoCode.ML => ml_,
      IsoCode.MM => mm_,
      IsoCode.MN => mn_,
      IsoCode.MO => mo_,
      IsoCode.MP => mp_,
      IsoCode.MQ => mq_,
      IsoCode.MR => mr_,
      IsoCode.MS => ms_,
      IsoCode.MT => mt_,
      IsoCode.MU => mu_,
      IsoCode.MV => mv_,
      IsoCode.MW => mw_,
      IsoCode.MX => mx_,
      IsoCode.MY => my_,
      IsoCode.MZ => mz_,
      IsoCode.NA => na_,
      IsoCode.NC => nc_,
      IsoCode.NE => ne_,
      IsoCode.NF => nf_,
      IsoCode.NG => ng_,
      IsoCode.NI => ni_,
      IsoCode.NL => nl_,
      IsoCode.NO => no_,
      IsoCode.NP => np_,
      IsoCode.NR => nr_,
      IsoCode.NU => nu_,
      IsoCode.NZ => nz_,
      IsoCode.OM => om_,
      IsoCode.PA => pa_,
      IsoCode.PE => pe_,
      IsoCode.PF => pf_,
      IsoCode.PG => pg_,
      IsoCode.PH => ph_,
      IsoCode.PK => pk_,
      IsoCode.PL => pl_,
      IsoCode.PM => pm_,
      IsoCode.PR => pr_,
      IsoCode.PS => ps_,
      IsoCode.PT => pt_,
      IsoCode.PW => pw_,
      IsoCode.PY => py_,
      IsoCode.QA => qa_,
      IsoCode.RE => re_,
      IsoCode.RO => ro_,
      IsoCode.RS => rs_,
      IsoCode.RU => ru_,
      IsoCode.RW => rw_,
      IsoCode.SA => sa_,
      IsoCode.SB => sb_,
      IsoCode.SC => sc_,
      IsoCode.SD => sd_,
      IsoCode.SE => se_,
      IsoCode.SG => sg_,
      IsoCode.SH => sh_,
      IsoCode.SI => si_,
      IsoCode.SJ => sj_,
      IsoCode.SK => sk_,
      IsoCode.SL => sl_,
      IsoCode.SM => sm_,
      IsoCode.SN => sn_,
      IsoCode.SO => so_,
      IsoCode.SR => sr_,
      IsoCode.SS => ss_,
      IsoCode.ST => st_,
      IsoCode.SV => sv_,
      IsoCode.SX => sx_,
      IsoCode.SY => sy_,
      IsoCode.SZ => sz_,
      IsoCode.TA => ta_,
      IsoCode.TC => tc_,
      IsoCode.TD => td_,
      IsoCode.TG => tg_,
      IsoCode.TH => th_,
      IsoCode.TJ => tj_,
      IsoCode.TK => tk_,
      IsoCode.TL => tl_,
      IsoCode.TM => tm_,
      IsoCode.TN => tn_,
      IsoCode.TO => to_,
      IsoCode.TR => tr_,
      IsoCode.TT => tt_,
      IsoCode.TV => tv_,
      IsoCode.TW => tw_,
      IsoCode.TZ => tz_,
      IsoCode.UA => ua_,
      IsoCode.UG => ug_,
      IsoCode.US => us_,
      IsoCode.UY => uy_,
      IsoCode.UZ => uz_,
      IsoCode.VA => va_,
      IsoCode.VC => vc_,
      IsoCode.VE => ve_,
      IsoCode.VG => vg_,
      IsoCode.VI => vi_,
      IsoCode.VN => vn_,
      IsoCode.VU => vu_,
      IsoCode.WF => wf_,
      IsoCode.WS => ws_,
      IsoCode.XK => xk_,
      IsoCode.YE => ye_,
      IsoCode.YT => yt_,
      IsoCode.ZA => za_,
      IsoCode.ZM => zm_,
      IsoCode.ZW => zw_,
    };
  }
}
